@@ -64,22 +64,19 @@
 #'   where \eqn{x} is the value of a marker, \eqn{\overline{x}} is the mean of the marker
 #'    and \eqn{sd(x)} is the standard deviation of the marker.
 #'
-#' \item \bold{Range (a.k.a. min-max scaling)} \code{(range)}: This method transforms data to
-#' a specific range, between 0 and 1. The formula for this method is:
-#' \deqn{Range = \frac{x - min(x)}{max(x) - min(x)}}
+#' \item \bold{min_max_scale} \code{(min_max_scale)}: This method transforms data to
+#' a specific scale, between 0 and 1. The formula for this method is:
+#' \deqn{min_max_scale = \frac{x - min(x)}{max(x) - min(x)}}
 #'
-#' \item \bold{Mean} \code{(mean)}: This method, which helps
-#' to understand the relative size of a single observation concerning
-#' the mean of dataset, calculates the ratio of each data point to the mean value
-#' of the dataset.
-#' \deqn{Mean =  \frac{x}{\overline{x}}}
+#' \item \bold{scale_mean_to_one} \code{(scale_mean_to_one)}: This method scales
+#' the arithmetic mean to 1. The formula for this method is:
+#' \deqn{scale_mean_to_one =  \frac{x}{\overline{x}}}
 #' where \eqn{x} is the value of a marker and \eqn{\overline{x}} is the mean of the marker.
 #'
-#' \item \bold{Deviance} \code{(deviance)}: This method, which allows for
+#' \item \bold{scale_sd_to_one} \code{(scale_sd_to_one)}: This method, which allows for
 #' comparison of individual data points in relation to the overall spread of
-#' the data, calculates the ratio of each data point to the standard deviation
-#' of the dataset.
-#' \deqn{Deviance = \frac{x}{sd(x)}}
+#' the data, scales the standard deviation to 1. The formula for this method is:
+#' \deqn{scale_sd_to_one = \frac{x}{sd(x)}}
 #' where \eqn{x} is the value of a marker and \eqn{sd(x)} is the standard deviation of the marker.
 #' }
 #'
@@ -174,8 +171,8 @@ mathComb <- function(markers = NULL,
                        "kumar-johnson"
                      ),
                      standardize = c(
-                       "none", "range",
-                       "zScore", "tScore", "mean", "deviance"
+                       "none", "min_max_scale",
+                       "zScore", "tScore", "scale_mean_to_one", "scale_sd_to_one"
                      ),
                      transform = c("none", "log", "exp", "sin", "cos"),
                      show.plot = TRUE,
@@ -216,7 +213,7 @@ mathComb <- function(markers = NULL,
     )
 
   standardizes <-
-    c("none", "range", "zScore", "tScore", "mean", "deviance")
+    c("none", "min_max_scale", "zScore", "tScore", "scale_mean_to_one", "scale_sd_to_one")
 
   transforms <- c("none", "log", "exp", "sin", "cos")
 
@@ -330,8 +327,8 @@ mathComb <- function(markers = NULL,
   if (length(which(standardizes == standardize)) == 0) {
     stop(
       paste(
-        "standardize should be one of 'range', 'zScore', 'tScore',",
-        "'mean', 'deviance'"
+        "standardize should be one of 'min_max_scale', 'zScore', 'tScore',",
+        "'scale_mean_to_one', 'scale_sd_to_one'"
       )
     )
   }
