@@ -204,7 +204,7 @@ test_that("nonlinComb functions ...", {
       standardize = "asdada",
       cutoff.method = "Youden"
     ),
-    "standardize should be one of 'range', 'zScore', 'tScore', 'mean', 'deviance'"
+    "standardize should be one of 'min_max_scale', 'zScore', 'tScore', 'scale_mean_to_one', 'scale_sd_to_one'"
   )
 
   expect_error(
@@ -239,7 +239,7 @@ test_that("nonlinComb functions ...", {
       event = "1",
       method = "splines",
       resample = "sada",
-      standardize = "range",
+      standardize = "min_max_scale",
       direction = "<",
       cutoff.method = "Youden"
     ),
